  %% integration time (yrs):
  p.integration_time=2.5e6;

  % units-related constants: 
  % one mole of C weights 12g; 
  %  ==> 1g C=(1/12) mole ==> 1kg C=(1000/12) mole = (1.e9/12)micro mole
  p.micromole_per_kg_C=1.e9/12;
  p.Carbon_mass_to_molality=60.8;
  p.ocean_mass_kg=13700*1e17; % also roughly equal to volume in liters
  p.ocean_area_meter=p.ocean_mass_kg*1.e-3/4000; %% meter^2

  % parameters:
  p.delta_in=-6;
  p.alpha_remin_frac=0.99;
  p.epsilon=-28; %% fractionation during organic matter production

  %% specified adjustment times in years:
  p.tau_ep=0.3e6;
  p.tau_CaCO3_dissolution=5.0e3; 
  p.tau_mixing=3.e3;
  p.tau_pyrite=3.e3;
  p.tau_siderite=3.e3;

  %% functional form of the forcing function: 'gaussian' or 'step'
  p.H_form='step';

  %% specify characteristics of change during decrease in productivity:
  %% fraction of exported organic matter undergoing sulfate reduction:
  p.t0=1.5e6;
  %% amplitude of perturbation to exported organic matter:
  p.Delta_ep=1.0;
  %% amplitude of perturbation to volcano co2 flux:
  p.Delta_F_in=0.0;
  %% fraction of exported organic matter undergoing sulfate reduction:
  p.alpha_scenario=1.0;
  %% drop in aerobic remineralization as fraction of exported organic matter:
  p.beta_scenario=1.0;
  %% drop in aerobic production as fraction of exported organic matter:
  p.gamma_scenario=0.0;
  %% increase in iron remineralization as fraction of exported organic matter:
  p.eta_scenario=0.0;
  %% an initial perturbation to DIC, mostly for looking at
  %% carbonate system adjustment time scale, a factor that's equal
  %% to a small nondim number.  Set to 0 for no perturbation: 
  p.Delta_M_inorg_initial_perturbation=0.0;

  %% initial conditions:
  p.M_org_init=250.0;
  p.M_inorg_init=35.0;
  p.F_prod0=3.6e-3; % present day value is about 3.6e-2 Gt C/yr
  p.F_remin0=p.alpha_remin_frac*p.F_prod0; % Gt C/yr
  p.F_in0=0.15e-3; % 0.1e-3 Gt C/yr
  p.F_ep0=(1-p.alpha_remin_frac)*p.F_prod0; % Gt C/yr
  p.F_b_inorg0=(1-p.alpha_remin_frac)*p.F_prod0;
  p.F_in_Ca2p_ell0=1.14e-4*p.Carbon_mass_to_molality;

  %% parameters for geochemistry part of the model:
  %% Pressure used to calculate CaCO3 solubility produce constant:
  p.K_sp_pressure=500; %% in atm:
  p.Alk0=2300; % micromole/kg = micro molality
  p.B_T0=400;
  p.SO40=28000;
  p.H2S0=100;
  p.Ca2p0=10000.0; % micromole/kg
  p.Fe3p0=20000;
  p.Fe2p0=200;
  p.Temperature_C_0=5; % Celsius
  p.Salinity0=35;

  %% constant used in parameterization of fraction of volcanic CO2
  %% which goes into the ocean via silicate weathering:
  p.alpha_wthr0=0.8;
  p.alpha_SO4_remin=3.0;
  p.Gamma_Berner=6;
  p.Omega0=1;  % CaCO3 reference degree of saturation
  p.CaCO3_exponent=4.5;

  %% scaling and offseting the carbonate system variables:
  p.carb_sulf_scale=[1.0e-2,1.0,100,10,200,100 ...
          ,100,100 ...
          ,0.01,1,100,100];
  p.carb_sulf_offset=[0,0,300,10,2000,100 ...
          ,300,100 ...
          ,0,p.SO40,0,1000];
  p.carb_sulf_label=[ ...
    'Hp   ';'OHm  ';'CO2g ';'H2CO3';'HCO3m';'CO3m2' ...
    ;'BOH3 ';'BOH4m' ...
    ;'HSO4m';'SO4m2';'H2Saq';'HSm  '];
  p.carb_sulf_init_guess=[0.006, 3.6, 300, 10, 1800, 200, ...
                300, 100, ...
                0, p.SO40, 0, 0];

  indx=0;
  indx=indx+1; p.prognostic_index.delta_org=indx;
  indx=indx+1; p.prognostic_index.delta_inorg=indx;
  indx=indx+1; p.prognostic_index.M_org=indx;
  indx=indx+1; p.prognostic_index.M_inorg=indx;
  indx=indx+1; p.prognostic_index.Alk=indx;
  indx=indx+1; p.prognostic_index.SO4_T=indx;
  indx=indx+1; p.prognostic_index.H2S_T=indx;
  indx=indx+1; p.prognostic_index.Fe3p=indx;
  indx=indx+1; p.prognostic_index.Fe2p=indx;
  indx=indx+1; p.prognostic_index.Ca2p=indx;

  p.prognostic_offset(p.prognostic_index.delta_org)=-28;
  p.prognostic_offset(p.prognostic_index.delta_inorg)=0;
  p.prognostic_offset(p.prognostic_index.M_org)=0;
  p.prognostic_offset(p.prognostic_index.M_inorg)=0;
  p.prognostic_offset(p.prognostic_index.Alk)=2.0*p.SO40;
  p.prognostic_offset(p.prognostic_index.SO4_T)=p.SO40;
  p.prognostic_offset(p.prognostic_index.H2S_T)=p.H2S0;
  p.prognostic_offset(p.prognostic_index.Fe3p)=0;
  p.prognostic_offset(p.prognostic_index.Fe2p)=0;
  p.prognostic_offset(p.prognostic_index.Ca2p)=p.Ca2p0;

  p.prognostic_scale(p.prognostic_index.delta_org)=10;
  p.prognostic_scale(p.prognostic_index.delta_inorg)=10;
  p.prognostic_scale(p.prognostic_index.M_org)=30;
  p.prognostic_scale(p.prognostic_index.M_inorg)=30;
  p.prognostic_scale(p.prognostic_index.Alk)=100;
  p.prognostic_scale(p.prognostic_index.SO4_T)=100;
  p.prognostic_scale(p.prognostic_index.H2S_T)=100;
  p.prognostic_scale(p.prognostic_index.Fe3p)=100;
  p.prognostic_scale(p.prognostic_index.Fe2p)=100;
  p.prognostic_scale(p.prognostic_index.Ca2p)=100;

  p.prognostic_label(p.prognostic_index.delta_org,:)  ='delta_org  ';
  p.prognostic_label(p.prognostic_index.delta_inorg,:)='delta_inorg';
  p.prognostic_label(p.prognostic_index.M_org,:)      ='M_org      ';
  p.prognostic_label(p.prognostic_index.M_inorg,:)    ='M_inorg    ';
  p.prognostic_label(p.prognostic_index.Alk,:)        ='Alk        ';
  p.prognostic_label(p.prognostic_index.SO4_T,:)      ='SO4_T      ';
  p.prognostic_label(p.prognostic_index.H2S_T,:)      ='H2S_T      ';
  p.prognostic_label(p.prognostic_index.Fe3p,:)       ='Fe3p       ';
  p.prognostic_label(p.prognostic_index.Fe2p,:)       ='Fe2p       ';
  p.prognostic_label(p.prognostic_index.Ca2p,:)       ='Ca2p       ';

  % options for fsolve, for carbonate system solution:
  p.optim_options=optimset('MaxIter',1000,'MaxFunEvals',1000 ...
                           ,'DerivativeCheck','off','Display','off' ...
                           ,'Jacobian','on' ...
                           );
  %                 ,'DiffMaxChange',1.e-7 ...
  %                 ,'TolFun',1.e-7,'TolX',1.e-7 ...

  % options for ode solver:
  p.ode_options=odeset('RelTol',1.0e-6,'AbsTol',1.e-6,'MaxStep',1e3);
  
  %% plotting controls:
  p.fig1_plot_panels=[1 1 1 1 1 1 1 1 1];
  p.fig1_panel_order=[1 2 3 4 5 6 7 8 9];
  p.fig1_nrows_ncols=[3 3];
  p.fig1_page_size_inches=[12 6]; % width, height

  %% logical switches:
  p.do_calc_pCO2=1;
  p.carbonate_system_solver='sulfur';  % 'standard', 'sulfur' or 'approx'
  p.do_CaCO3_dissolution=0;
  p.do_interactive_alpha_wthr=0;
  p.do_write_restart=1;
  p.do_read_restart=1;
  p.do_use_Ksp_aragonite=0;
  p.do_constant_Alk=0;
  p.do_prognostic_Ca2p=1;
  p.do_sulfate_remineralization=1;
  p.do_H2S_mixing_and_oxidation=0;
  p.do_pyrite_formation=0;
  p.do_iron_remineralization=0;
  p.do_Fe2p_mixing_and_oxidation=0;
  p.do_siderite_formation=0;
  p.do_run_model=1;
  p.do_save_figures_as_pdf=1;
  p.do_save_figures_as_Fig_files=1;
